@@ -43,7 +43,6 @@
 #include <KCalUtils/IncidenceFormatter>
 
 #include <KIdentityManagement/Identity>
-#include <KIdentityManagement/IdentityManager>
 
 #include <AkonadiCore/Item>
 
@@ -79,15 +78,6 @@ using namespace KCalUtils;
 static int defSuspendVal = 5;
 static int defSuspendUnit = 0; // 0=>minutes, 1=>hours, 2=>days, 3=>weeks
 
-class ReminderTree : public QTreeWidget
-{
-public:
-    ReminderTree(QWidget *parent) : QTreeWidget(parent)
-    {
-    }
-
-};
-
 class ReminderTreeItem : public QTreeWidgetItem
 {
 public:
@@ -95,13 +85,13 @@ public:
         : QTreeWidgetItem(parent), mIncidence(incidence), mNotified(false)
     {
     }
-    bool operator<(const QTreeWidgetItem &other) const Q_DECL_OVERRIDE;
+    bool operator<(const QTreeWidgetItem &other) const override;
 
     QString mDisplayText;
 
     const Akonadi::Item mIncidence;
     QDateTime mRemindAt;
-    KDateTime mTrigger;
+    QDateTime mTrigger;
     KDateTime mHappening;
     bool mNotified;
 };
@@ -154,9 +144,8 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     }
     setWindowTitle(i18nc("@title:window", "Reminders"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("korgac")));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok, this);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(topBox);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -198,7 +187,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
         topBox);
     mTopLayout->addWidget(label);
 
-    mIncidenceTree = new ReminderTree(topBox);
+    mIncidenceTree = new QTreeWidget(topBox);
     mIncidenceTree->setColumnCount(3);
     mIncidenceTree->setSortingEnabled(true);
     const QStringList headerLabels =
@@ -225,7 +214,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
 
     connect(mIncidenceTree, &QTreeWidget::itemClicked, this, &AlarmDialog::update);
     connect(mIncidenceTree, &QTreeWidget::itemDoubleClicked, this, &AlarmDialog::edit);
-    connect(mIncidenceTree, &ReminderTree::itemSelectionChanged, this, &AlarmDialog::updateButtons);
+    connect(mIncidenceTree, &QTreeWidget::itemSelectionChanged, this, &AlarmDialog::updateButtons);
 
     mDetailView = new CalendarSupport::IncidenceViewer(mCalendar.data(), topBox);
     const QString s = xi18nc("@info default incidence details string",
@@ -333,7 +322,7 @@ void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem,
     item->mNotified = false;
     item->mHappening = KDateTime();
     item->mRemindAt = reminderAt;
-    item->mTrigger = KDateTime::currentLocalDateTime();
+    item->mTrigger = QDateTime::currentDateTime();
     item->mDisplayText = displayText;
     item->setText(0, cleanSummary(incidence->summary()));
 
@@ -350,8 +339,7 @@ void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem,
     item->mHappening = dateTime;
     item->setText(1, displayStr);
 
-    item->setText(2, IncidenceFormatter::dateTimeToString(
-                      item->mTrigger, false, true, KDateTime::Spec::LocalZone()));
+    item->setText(2, QLocale().toString(item->mTrigger, QLocale::ShortFormat));
     QString tip =
         IncidenceFormatter::toolTipStr(
             CalendarSupport::displayName(mCalendar.data(), incidenceitem.parentCollection()),
@@ -401,12 +389,13 @@ void AlarmDialog::dismissCurrent()
 {
     dismiss(selectedItems());
 
-    if (activeCount() == 0) {
+    const int activeCountNumber = activeCount();
+    if (activeCountNumber == 0) {
         accept();
     } else {
         update();
     }
-    Q_EMIT reminderCount(activeCount());
+    Q_EMIT reminderCount(activeCountNumber);
 }
 
 void AlarmDialog::dismissAll()
@@ -427,11 +416,11 @@ void AlarmDialog::dismissAll()
     Q_EMIT reminderCount(activeCount());
 }
 
-void AlarmDialog::dismiss(ReminderList selections)
+void AlarmDialog::dismiss(const ReminderList &selections)
 {
     QList<Akonadi::Item::Id> ids;
     ids.reserve(selections.count());
-    for (ReminderList::Iterator it = selections.begin(); it != selections.end(); ++it) {
+    for (ReminderList::const_iterator it = selections.constBegin(); it != selections.constEnd(); ++it) {
         qCDebug(KOALARMCLIENT_LOG) << "removing " << CalendarSupport::incidence((*it)->mIncidence)->summary();
         if (mIncidenceTree->itemBelow(*it)) {
             mIncidenceTree->setCurrentItem(mIncidenceTree->itemBelow(*it));
@@ -449,20 +438,19 @@ void AlarmDialog::dismiss(ReminderList selections)
 void AlarmDialog::edit()
 {
     ReminderList selection = selectedItems();
-    if (selection.count() != 1) {
-        return;
-    }
-    Incidence::Ptr incidence = CalendarSupport::incidence(selection.first()->mIncidence);
-    if (!mCalendar->hasRight(selection.first()->mIncidence, Akonadi::Collection::CanChangeItem)) {
-        KMessageBox::sorry(
-            this,
-            i18nc("@info",
-                  "\"%1\" is a read-only item so modifications are not possible.",
-                  cleanSummary(incidence->summary())));
-        return;
-    }
+    if (selection.count() == 1) {
+        Incidence::Ptr incidence = CalendarSupport::incidence(selection.first()->mIncidence);
+        if (!mCalendar->hasRight(selection.first()->mIncidence, Akonadi::Collection::CanChangeItem)) {
+            KMessageBox::sorry(
+                        this,
+                        i18nc("@info",
+                              "\"%1\" is a read-only item so modifications are not possible.",
+                              cleanSummary(incidence->summary())));
+            return;
+        }
 
-    openIncidenceEditorNG(selection.first()->mIncidence);
+        openIncidenceEditorNG(selection.first()->mIncidence);
+    }
 }
 
 void AlarmDialog::suspend()
@@ -475,12 +463,24 @@ void AlarmDialog::suspend()
     switch (mSuspendUnit->currentIndex()) {
     case 3: // weeks
         unit *=  7;
+#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        Q_FALLTHROUGH();
+#endif
     case 2: // days
         unit *= 24;
+#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        Q_FALLTHROUGH();
+#endif
     case 1: // hours
         unit *= 60;
+#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        Q_FALLTHROUGH();
+#endif
     case 0: // minutes
         unit *= 60;
+#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        Q_FALLTHROUGH();
+#endif
     default:
         break;
     }
@@ -833,7 +833,7 @@ void AlarmDialog::showDetails(QTreeWidgetItem *item)
         mDetailView->setIncidence(Akonadi::Item());
     } else {
         if (!reminderItem->mDisplayText.isEmpty()) {
-            QString txt = QLatin1String("<qt><p><b>") + reminderItem->mDisplayText + QLatin1String("</b></p></qt>");
+            const QString txt = QLatin1String("<qt><p><b>") + reminderItem->mDisplayText + QLatin1String("</b></p></qt>");
             mDetailView->setHeaderText(txt);
         } else {
             mDetailView->setHeaderText(QString());
@@ -893,9 +893,10 @@ KDateTime AlarmDialog::triggerDateForIncidence(const Incidence::Ptr &incidence,
 void AlarmDialog::slotCalendarChanged()
 {
     KCalCore::Incidence::List incidences = mCalendar->incidences();
-    Akonadi::Item::List items = mCalendar->itemList(incidences);
+    const Akonadi::Item::List items = mCalendar->itemList(incidences);
+    Akonadi::Item::List::ConstIterator end(items.constEnd());
     for (Akonadi::Item::List::ConstIterator it = items.constBegin();
-            it != items.constEnd(); ++it) {
+            it != end; ++it) {
         ReminderTreeItem *item = searchByItem(*it);
 
         if (item) {
@@ -975,9 +976,9 @@ bool AlarmDialog::openIncidenceEditorThroughKOrganizer(const Incidence::Ptr &inc
     }
 #elif defined(Q_OS_WIN)
     // WId is a typedef to a void* on windows
-    QDBusReply<qlonglong> reply = korganizerObj.call(QStringLiteral("winId"));
+    QDBusReply<int> reply = korganizerObj.call(QStringLiteral("winId"));
     if (reply.isValid()) {
-        qlonglong window = reply;
+        int window = reply;
         KWindowSystem::minimizeWindow(winId(), false);
         KWindowSystem::allowExternalProcessWindowActivation();
         KWindowSystem::activateWindow(reinterpret_cast<WId>(window));
@@ -994,7 +995,7 @@ bool AlarmDialog::openIncidenceEditorNG(const Akonadi::Item &item)
     IncidenceEditorNG::IncidenceDialog *dialog =
         IncidenceEditorNG::IncidenceDialogFactory::create(
             false, /*doesn't need initial saving*/
-            incidence->type(), 0, this);
+            incidence->type(), nullptr, this);
     dialog->load(item);
     return true;
 }
