@@ -32,8 +32,6 @@
 #include "akonadicollectionview.h"
 #include "calendaradaptor.h"
 #include "calendarview.h"
-#include "job/htmlexportjob.h"
-#include "htmlexportsettings.h"
 #include "kocore.h"
 #include "kodialogmanager.h"
 #include "korganizeradaptor.h"
@@ -85,7 +83,6 @@
 #include <QTemporaryFile>
 #include <KToggleAction>
 #include <KWindowSystem>
-#include <KIO/NetAccess>
 #include <KNS3/DownloadDialog>
 #include <QIcon>
 #include "korganizer_debug.h"
@@ -114,7 +111,6 @@ ActionManager::ActionManager(KXMLGUIClient *client, CalendarView *widget,
     mCalendarView = widget;
     mIsPart = isPart;
     mTempFile = nullptr;
-    mHtmlExportSync = false;
     mMainWindow = mainWindow;
     mMenuBar = menuBar;
 }
@@ -169,14 +165,6 @@ void ActionManager::init()
     // initialize the QAction instances
     initActions();
 
-    // set up autoExporting stuff
-    mAutoExportTimer = new QTimer(this);
-    connect(mAutoExportTimer, &QTimer::timeout, this, &ActionManager::checkAutoExport);
-    if (KOPrefs::instance()->mAutoExport &&
-            KOPrefs::instance()->mAutoExportInterval > 0) {
-        mAutoExportTimer->start(1000 * 60 * KOPrefs::instance()->mAutoExportInterval);
-    }
-
     // set up autoSaving stuff
     mAutoArchiveTimer = new QTimer(this);
     mAutoArchiveTimer->setSingleShot(true);
@@ -194,8 +182,6 @@ void ActionManager::init()
 
     connect(mCalendarView, &CalendarView::incidenceSelected,
             this, &ActionManager::processIncidenceSelection);
-    connect(mCalendarView, SIGNAL(exportHTML(KOrg::HTMLExportSettings*)),
-            this, SLOT(exportHTML(KOrg::HTMLExportSettings*)));
 
     processIncidenceSelection(Akonadi::Item(), QDate());
 
@@ -294,10 +280,6 @@ void ActionManager::initActions()
     mACollection->addAction(QStringLiteral("downloadnewstuff"), action);
     connect(action, &QAction::triggered, this, &ActionManager::downloadNewStuff);
 
-    action = new QAction(i18n("Export &Web Page..."), this);
-    mACollection->addAction(QStringLiteral("export_web"), action);
-    connect(action, &QAction::triggered, mCalendarView, &CalendarView::exportWeb);
-
     action = new QAction(i18n("Export as &iCalendar..."), this);
     mACollection->addAction(QStringLiteral("export_icalendar"), action);
     connect(action, &QAction::triggered, mCalendarView, &CalendarView::exportICalendar);
@@ -767,7 +749,6 @@ void ActionManager::slotMergeFinished(bool success, int total)
 void ActionManager::slotNewResourceFinished(bool success)
 {
     Q_ASSERT(sender());
-    sender()->deleteLater();
     Akonadi::ICalImporter *importer = qobject_cast<Akonadi::ICalImporter *>(sender());
     mImportAction->setEnabled(true);
     if (success) {
@@ -775,6 +756,7 @@ void ActionManager::slotNewResourceFinished(bool success)
     } else {
         mCalendarView->showMessage(i18n("Could not add a calendar. Error: %1", importer->errorMessage()), KMessageWidget::Error);
     }
+    sender()->deleteLater();
 }
 
 void ActionManager::readSettings()
@@ -824,13 +806,6 @@ void ActionManager::writeSettings()
     config->sync();
 }
 
-/*
-void ActionManager::file_new()
-{
-  Q_EMIT actionNewMainWindow();
-}
-*/
-
 void ActionManager::file_open()
 {
     const QString defaultPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/korganizer/");
@@ -922,8 +897,8 @@ bool ActionManager::importURL(const QUrl &url, bool merge)
     Akonadi::ICalImporter *importer = new Akonadi::ICalImporter();
     bool jobStarted;
     if (merge) {
-        connect(importer, &Akonadi::ICalImporter::importIntoExistingFinished, this, &ActionManager::slotMergeFinished),
-                jobStarted = importer->importIntoExistingResource(url, Akonadi::Collection());
+        connect(importer, &Akonadi::ICalImporter::importIntoExistingFinished, this, &ActionManager::slotMergeFinished);
+        jobStarted = importer->importIntoExistingResource(url, Akonadi::Collection());
     } else {
         connect(importer, &Akonadi::ICalImporter::importIntoNewFinished, this, &ActionManager::slotNewResourceFinished);
         jobStarted = importer->importIntoNewResource(url.path());
@@ -994,91 +969,6 @@ bool ActionManager::saveURL()
     return true;
 }
 
-void ActionManager::exportHTML()
-{
-    HTMLExportSettings *settings = new HTMLExportSettings(QStringLiteral("KOrganizer"));
-    mSettingsToFree.insert(settings);
-    // Manually read in the config, because parametrized kconfigxt objects don't
-    // seem to load the config theirselves
-    settings->load();
-
-    const QDate qd1 = QDate::currentDate();
-    QDate qd2 = qd1;
-
-    if (settings->monthView()) {
-        qd2 = qd2.addMonths(1);
-    } else {
-        qd2 = qd2.addDays(7);
-    }
-    settings->setDateStart(QDateTime(qd1));
-    settings->setDateEnd(QDateTime(qd2));
-
-    exportHTML(settings, true/*autoMode*/);
-}
-
-void ActionManager::exportHTML(KOrg::HTMLExportSettings *settings, bool autoMode)
-{
-    if (!settings) {
-        qCWarning(KORGANIZER_LOG) << "Settings is null" << settings;
-        return;
-    }
-
-    if (settings->outputFile().isEmpty()) {
-        int result = KMessageBox::questionYesNo(
-                         dialogParent(),
-                         i18n("The HTML calendar export file has not been specified yet.\n"
-                              "Do you want to set it now?\n\n"
-                              "If you answer \"no\" then this export operation will be canceled"),
-                         QString());
-        if (result == KMessageBox::No) {
-            mMainWindow->showStatusMessage(
-                i18nc("@info:status",
-                      "Calendar HTML operation canceled due to unspecified output file name"));
-            return;
-        }
-
-        const QString fileName =
-            QFileDialog::getSaveFileName(dialogParent(), i18n("Select path for HTML calendar export"),
-                                         QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation),
-                                         i18n("HTML Files (*.html)"));
-        settings->setOutputFile(fileName);
-        settings->save();
-    }
-
-    if (!autoMode && QFileInfo(settings->outputFile()).exists()) {
-        if (KMessageBox::warningContinueCancel(
-                    dialogParent(),
-                    i18n("Do you want to overwrite file \"%1\"?",
-                         settings->outputFile()),
-                    QString(),
-                    KStandardGuiItem::overwrite()) == KMessageBox::Cancel) {
-            mMainWindow->showStatusMessage(
-                i18nc("@info:status",
-                      "Calendar HTML operation canceled due to output file overwrite"));
-            return;
-        }
-    }
-
-    settings->setEMail(CalendarSupport::KCalPrefs::instance()->email());
-    settings->setName(CalendarSupport::KCalPrefs::instance()->fullName());
-
-    settings->setCreditName(QStringLiteral("KOrganizer"));
-    settings->setCreditURL(QStringLiteral("http://korganizer.kde.org"));
-
-    KOrg::HtmlExportJob *exportJob = new KOrg::HtmlExportJob(calendar(), settings, autoMode, mMainWindow, view());
-
-    if (KOGlobals::self()->holidays()) {
-        const KHolidays::Holiday::List holidays = KOGlobals::self()->holidays()->holidays(
-                                                settings->dateStart().date(), settings->dateEnd().date());
-        for (const KHolidays::Holiday &holiday : holidays) {
-            exportJob->addHoliday(holiday.observedStartDate(), holiday.name());
-        }
-    }
-
-    connect(exportJob, &KOrg::HtmlExportJob::result, this, &ActionManager::handleExportJobResult);
-    exportJob->start();
-}
-
 bool ActionManager::saveAsURL(const QUrl &url)
 {
     qCDebug(KORGANIZER_LOG) << url.toDisplayString();
@@ -1110,7 +1000,6 @@ bool ActionManager::saveAsURL(const QUrl &url)
     if (success) {
         delete mTempFile;
         mTempFile = tempFile;
-        KIO::NetAccess::removeTempFile(fileOrig);
         setTitle();
     } else {
         KMessageBox::sorry(dialogParent(),
@@ -1125,45 +1014,6 @@ bool ActionManager::saveAsURL(const QUrl &url)
     return success;
 }
 
-#ifdef AKONADI_PORT_DISABLED // can go away, kept for reference
-bool ActionManager::saveModifiedURL()
-{
-
-    // If calendar isn't modified do nothing.
-    if (!mCalendarView->isModified()) {
-        return true;
-    }
-
-    mHtmlExportSync = true;
-    if (KOPrefs::instance()->mAutoSave && !mURL.isEmpty()) {
-        // Save automatically, when auto save is enabled.
-        return saveURL();
-    } else {
-        int result = KMessageBox::warningYesNoCancel(
-                         dialogParent(),
-                         i18n("The calendar has been modified.\nDo you want to save it?"),
-                         QString(),
-                         KStandardGuiItem::save(), KStandardGuiItem::discard());
-        switch (result) {
-        case KMessageBox::Yes:
-            if (mURL.isEmpty()) {
-                QUrl url = getSaveURL();
-                return saveAsURL(url);
-            } else {
-                return saveURL();
-            }
-        case KMessageBox::No:
-            return true;
-        case KMessageBox::Cancel:
-        default: {
-            mHtmlExportSync = false;
-            return false;
-        }
-        }
-    }
-}
-#endif
-
 QUrl ActionManager::getSaveURL()
 {
     QUrl url =
@@ -1444,7 +1294,7 @@ public:
     }
 
 protected:
-    bool visit(const KCalCore::Event::Ptr &) Q_DECL_OVERRIDE {
+    bool visit(const KCalCore::Event::Ptr &) override {
         if (mShow)
         {
             mShow->setText(i18n("&Show Event"));
@@ -1460,7 +1310,7 @@ protected:
         return true;
     }
 
-    bool visit(const KCalCore::Todo::Ptr &) Q_DECL_OVERRIDE {
+    bool visit(const KCalCore::Todo::Ptr &) override {
         if (mShow)
         {
             mShow->setText(i18n("&Show To-do"));
@@ -1476,11 +1326,11 @@ protected:
         return true;
     }
 
-    bool visit(const KCalCore::Journal::Ptr &) Q_DECL_OVERRIDE {
+    bool visit(const KCalCore::Journal::Ptr &) override {
         return assignDefaultStrings();
     }
 
-    bool visit(const KCalCore::FreeBusy::Ptr &) Q_DECL_OVERRIDE { // to inhibit hidden virtual compile warning
+    bool visit(const KCalCore::FreeBusy::Ptr &) override { // to inhibit hidden virtual compile warning
         return false;
     }
 
@@ -1565,7 +1415,7 @@ void ActionManager::keyBindings()
         dlg.addCollection(mMainWindow->getActionCollection());
     }
 
-    foreach (KOrg::Part *part, mParts) {
+    for (KOrg::Part *part : qAsConst(mParts)) {
         if (part) {
             dlg.addCollection(part->actionCollection(), part->shortInfo());
         }
@@ -1892,19 +1742,6 @@ QWidget *ActionManager::dialogParent()
     return mCalendarView->topLevelWidget();
 }
 
-void ActionManager::checkAutoExport()
-{
-    // Don't save if auto save interval is zero
-    if (KOPrefs::instance()->mAutoExportInterval == 0) {
-        return;
-    }
-
-    // has this calendar been saved before? If yes automatically save it.
-    if (KOPrefs::instance()->mAutoExport) {
-        exportHTML();
-    }
-}
-
 void ActionManager::openTodoEditor(const QString &summary,
                                    const QString &description,
                                    const QStringList &attachmentUris,
@@ -1937,17 +1774,6 @@ void ActionManager::openEventEditor(const QString &summary,
     qCWarning(KORGANIZER_LOG) << "Not implemented in korg-desktop";
 }
 
-void ActionManager::handleExportJobResult(KJob *job)
-{
-    HtmlExportJob *htmlExportJob = qobject_cast<HtmlExportJob *>(job);
-    Q_ASSERT(htmlExportJob);
-
-    if (mSettingsToFree.contains(htmlExportJob->settings())) {
-        mSettingsToFree.remove(htmlExportJob->settings());
-        delete htmlExportJob->settings();
-    }
-}
-
 void ActionManager::setHelpText(QAction *act, const QString &text)
 {
     act->setStatusTip(text);
